
----------------------------------------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------------------------------------
-- File:        MapOptions.lua
-- Description: Custom MapOptions file that makes possible to set up variable options before game starts, like ModOptions.lua
-- Author:      SirArtturi, Lurker, Smoth, jK
----------------------------------------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------------------------------------
--	NOTES:
--	- using an enumerated table lets you specify the options order
--
--	These keywords must be lowercase for LuaParser to read them.
--
--	key:			the string used in the script.txt
--	name:		 the displayed name
--	desc:		 the description (could be used as a tooltip)
--	type:		 the option type
--	def:			the default value
--	min:			minimum value for number options
--	max:			maximum value for number options
--	step:		 quantization step, aligned to the def value
--	maxlen:	 the maximum string length for string options
--	items:		array of item strings for list options
--	scope:		'all', 'player', 'team', 'allyteam'			<<< not supported yet >>>
--
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

local options = {
--	{
	

	{
		key   = 'resources',
		name  = 'Resouce amount',
		desc  = 'How much resources will be available?',
		type  = 'list',
		--section = 'Economy',
		def   = 'normal',
		items = {
			{ key = 'low', name = "Low", desc = "few resources" },
			{ key = 'normal', name = "Normal", desc = "normal amount" },
			{ key = 'high', name = "High", desc = "we shall live in prosperity" },
			{ key = 'madness', name = "Madness", desc = "look. look at all those minerals." },
		},
	},


	{
		key   = 'creep',
		name  = 'Mineral creep behaviour',
		desc  = 'How will mineral replenishment change with time?',
		type  = 'list',
		--section = 'Economy',
		def   = 'normal',
		items = {
			{ key = 'slow', name = "slow", desc = "spawning slow moves to middle" },
			{ key = 'normal', name = "normal", desc = "Resources in middle of map" },
			{ key = 'slowbutsteady', name = "slowbutsteady", desc = "Slow but steady creep towards middle that starts early" },
		},
	},

	{
		key   = 'middle',
		name  = 'Middle resources',
		desc  = 'Will there be resources in the middle of map?',
		type  = 'list',
		--section = 'Economy',
		def   = 'yesbutnotin1v1',
		items = {
			{ key = 'yesbutnotin1v1', name = "yesbutnotin1v1", desc = "In 1v1 no resources in middle, with any other player count: yes" },
			{ key = 'yes', name = "yes", desc = "Resources in middle of map" },
			{ key = 'no', name = "no", desc = "No resources in middle of map" },
		},
	},	

}

return options


